init_movement = function(Q) {

	Q.component("controls", {

		added: function() {
			this.pressed = {
				up: false,		down: false,
				left: false,	right: false,
				fire: false,	action: false,
			};
			this.oldPressed = Q._extend({}, this.pressed);

			this.entity.on('prestep',this,'step');
		},

		step: function() {
			this.oldPressed = Q._extend({}, this.pressed);
		},

		setPressed: function(button, state) {
			this.pressed[button] = state;
		},

		isPressed: function(button) {
			return this.pressed[button];
		},
		justPressed: function(button) {
			return this.pressed[button] && !this.oldPressed[button];
		},
		justReleased: function(button) {
			return this.oldPressed[button] && !this.pressed[button];
		},

	});

	Q.component("playercontrols", {
		added: function() {
			var entity = this.entity;
			if(!entity.has("controls"))
				entity.add("controls");

			entity.on('step',this,'step');
		},

		setFromInput: function(controls,button) {
			controls.setPressed(button, Q.inputs[button]);
		},

		step: function() {

			var controls = this.entity.controls;

			this.setFromInput(controls, 'left');
			this.setFromInput(controls, 'right');
			this.setFromInput(controls, 'up');
			this.setFromInput(controls, 'down');
			this.setFromInput(controls, 'fire');
			this.setFromInput(controls, 'action');

		},
	});

	Q.component("movement", {
		added: function() {

			var entity = this.entity;
			if(!entity.has("controls"))
				entity.add("controls");

			entity.p = Q._defaults(entity.p, {
				speed: 150,
				accel: 120,
				drag: 10.0,
			});

			entity.on('step',this,"step");
		},

		step: function(dt) {

			var p = this.entity.p,
				controls = this.entity.controls;

			var dragamount = (1.0 - Math.pow(p.drag*dt, 2));
		    p.vx *= dragamount;
		    p.vy *= dragamount;

		    if(controls.isPressed('left') && p.vx > -p.speed) {
		      p.vx -= p.accel * dt;
		    }
		    if(controls.isPressed('right') && p.vx < p.speed) {
		      p.vx += p.accel * dt;
		    }

		    if(controls.isPressed('up') && p.vy > -p.speed) {
		      p.vy -= p.accel * dt;
		    }
		    if(controls.isPressed('down') && p.vy < p.speed) {
		      p.vy += p.accel * dt;
		    }
		}

	});
	
};