init_player = function(Q) {

Q.sheet("chimp", "captain.png", {tilew: 32, tileh:32});

var chimpframes = {};
var totalframes = 8;
var rawlayout = [ ['idle', [1]],
                  ['move', [4]],
                  ['up', [2, 3]],
                  ['down', [5]], 
                  ['sit', [6]], ];
for(var i = 0; i < rawlayout.length; i++)
{
  var layout = rawlayout[i];
  var leftframes = [];
  var rightframes = [];
  for(var j = 0; j < layout[1].length; j++)
  {
    leftframes.push(layout[1][j]);
    rightframes.push(layout[1][j] + totalframes);
  }
  chimpframes[layout[0]+'_left'] = {frames:leftframes, rate: 1/3, loop: false};
  chimpframes[layout[0]+'_right'] = {frames:rightframes, rate: 1/3, loop: false};
}

Q.animations('chimp', chimpframes);

Q.Sprite.extend("Chimp", {
  
  init: function(p) {
    this._super(p, {
      sheet: 'chimp',
      sprite: 'chimp',
      type: Q.SPRITE_DEFAULT | Q.SPRITE_ACTIVE | Q.SPRITE_FRIENDLY,
      snap: true,
    });

    this.add('animation');
    this.add('2d');

    this.add('movement');
    this.add('playercontrols');    
    
    this._direction = 'left';
    this._anim = 'idle';

    this.on('animFrame');

    Q.input.on('action', this, 'action');
    this._driving = false;

    this.p.points = [ 
      [  0, -10  ],
      [  8, -8  ],
      [  8, 8  ],
      [  0, 10 ],
      [ -8, 8  ],
      [ -8, -8  ]
    ];

  },

  action: function() {

    //driving toggle
    if(this.p.x > 100 && !this._driving)
    {
      this._driving = true;
      this.p.vx = Math.max(0,this.p.vx);
      this._direction = 'right';
    }
    else
    {
      this._driving = false;
    }

    if(this._driving)
      this.container.trigger('driver', this);
    else
      this.container.trigger('driver', null);

    //planting toggle

    if(this.p.y < 0 && this.p.x > -30)
    {
      this.container.trigger('planting');
    }

    //fixing toggle

    if(this.p.y > 40 && this.p.x < -40)
    {
      this.container.trigger('fix');
    }

    //eating toggle

    if(this.p.y < 40 && this.p.y > 10 &&
        this.p.x < 80 && this.p.x > -20)
    {
      this.container.trigger('eat');
    }
  },

  step: function(dt) {
    var p = this.p;
    var save = Q.globals;

    //logic
      //movement handled in component

    //increment counters
    save.fatigue += dt;

    if(save.fatigue < 40)
    {
      save.hunger += dt * 1;
    }
    else if(save.fatigue > 100)
    {
      save.fatigue = 100;
      save.hunger += dt * 4;
    }
    else
    {
      save.hunger += dt * 2;
    }

    if(save.hunger > 100)
    {
      var dif = save.hunger - 100;
      save.hunger = 100;
      save.chimphp -= dif;
    }

    p.speed = 150;
    if(this._driving)
    {
      p.speed = 0;
    }

    //anim
    
    //change facing direction
    if(p.vx > 1)
      this._direction = 'right';
    else if(p.vx < -1)
      this._direction = 'left';
    
    //specfic animations
    var controls = this.controls;

    if(this._driving)
      this._anim = 'sit';
    else if(controls.isPressed('up'))
      this._anim = 'up';
    else if(controls.isPressed('down'))
      this._anim = 'down';
    else if(controls.isPressed('left') || controls.isPressed('right'))
      this._anim = 'move';
    else
      this._anim = 'idle';
    
    this.play(this._anim+'_'+this._direction);

  }

});

};