init_ship = function(Q) {

var shipPhysics = [
	[[-101,-3],[-77,-3],[-77,39],[-101,39]],
	[[-89,-10],[-75,-10],[-75,2],[-89,2]],
	[[-50,-9],[69,-9],[69,3],[-50,3]],
	[[-82,71],[-27,71],[-27,79],[-82,79]],
	[[-93,36],[-43,36],[-43,45],[-93,45]],
	[[67,-1],[82,-1],[82,15],[67,15]],
	[[81,3],[104,3],[104,12],[81,12]],
	[[105,4],[129,13],[130,21],[102,12]],
	[[117,18],[112,40],[131,45],[136,31],[127,17]],
	[[74,53],[144,53],[144,64],[74,64]],
	[[-79,-10],[-66,-42],[-72,-46],[-89,-9]],
	[[-72,-47],[44,-47],[44,-38],[-72,-38]],
	[[44,-44],[35,-38],[47,-6],[61,-8]],
	[[56,1],[68,13],[69,-1]],
	[[-114,-39],[-146,-9],[-144,49],[-115,76],[-101,19]],
	[[-100,-81],[-112,-22],[-81,-22],[-69,-48],[-76,-79]],
	[[-98,53],[-106,68],[-86,79],[-75,66]],
	[[-12,52],[65,52],[65,62],[-12,62]],
	[[-20,35],[129,35],[129,45],[-20,45]],
	[[-20,55],[-20,40],[-16,37],[-7,53]],
	[[-20,49],[-31,73],[-27,80],[-15,52]],
	[[-87,43],[-73,43],[-73,71],[-87,71]],
];

Q.sheet("plants", "plants.png", {tilew: 64, tileh:32});
Q.sheet("cabin", "cabin.png", {tilew: 64, tileh:32});

Q.Sprite.extend("Bullet", {
	init: function(p) {
		this._super(p, {asset:"bullet.png", type: Q.SPRITE_FRIENDLY, collisionMask: Q.SPRITE_ENEMY});
		this.add('2d');
		this.p.points = [
			[-10,0],
			[0,-10],
			[10,0],
			[0,10],
		];

		this.on("hit");
	},

	hit: function(col) {
		this.destroy();
	},
});

Q.Sprite.extend("Ship", {

	init: function(p) {
		this._super(p, {
			sort: true,
			snap: true,
		});

		this.on("inserted");

		this.add("2d");
		this.p.points = [[0,0]];

		this.on('driver');
		this._driver = null;

		this.on('fix');
		this.on('planting');
		this.on('eat');

		this._back = this._front = this._all = null;
	},

	step: function(dt) {

		//drag
		this.p.vy *= 0.99;
		this.p.vx *= 0.99;
		this.p.vx += dt * 5;

		this.p.angle *= 0.9;

		//animate the boosters based on these later
		var boost_up = false,
			boost_down = false,
			boost_straight = false,
			boost_back = false;

		if(this._driver) //driver controls
		{
			var controls = this._driver.controls;

			if(controls.isPressed('up'))
			{
				boost_up = true;
			}
			if(controls.isPressed('down'))
			{
				boost_down = true;
			}

			if(controls.isPressed('left'))
			{
				boost_back = true;
			}
			else if(controls.isPressed('right'))
			{
				boost_straight = true;
			}

			if(controls.justPressed('fire') && Q.globals.ammo > 0)
			{
				Q.globals.ammo--;

				var x = this.p.x;
				var y = this.p.y;

				var mat = Q.matrix2d();

				mat.rotateDeg(this.p.angle);

				var offset = mat.transform(140, 55);
				var normal = mat.transform(1, 0);

				mat.release();

				this.stage.insert(new Q.Bullet({
					x:x+offset[0], y:y+offset[1],
					vx: normal[0]*300 + this.p.vx,
					vy: normal[1]*300 + this.p.vy,
				}));

				Q.audio.play("shoot.ogg");
			}

			if(this._all)
				this._all.p.hidden = false;
			if(this._front)
				this._front.p.hidden = true;

			this.stage.viewport.scale = 1;
			this.stage.viewport.offsetX = -200;

		}
		else
		{
			if(this._all)
				this._all.p.hidden = true;
			if(this._front)
				this._front.p.hidden = false;

			this.stage.viewport.scale = 2;
			this.stage.viewport.offsetX = -100;
		}

		if(this._malfunction)
		{
			boost_up = Math.random() < 0.1;
			boost_down = Math.random() < 0.1;
			boost_straight = Math.random() < 0.1;
			boost_back = Math.random() < 0.1;
		}

		//react to boost controls
		if(boost_up)
		{
			this.p.vy -= dt * 60 * Q.globals.turning;
			this.p.vx += dt * 10 * Q.globals.speed;
			this.p.angle += 1.0 * Q.globals.turning;
		}
		if(boost_down)
		{
			this.p.vy += dt * 60 * Q.globals.turning;
			this.p.vx += dt * 10 * Q.globals.speed;
			this.p.angle -= 1.0	* Q.globals.turning;
		}

		if(boost_straight)
		{
			this.p.vx += dt * 100 * Q.globals.speed;
		}
		if(boost_back)
		{
			this.p.vx -= dt * 4;
		}

		//set booster sprites
		if(this._boosterup)
			this._boosterup.p.hidden = !boost_up;
		if(this._boosterdown)
			this._boosterdown.p.hidden = !boost_down;
		if(this._booster)
		{
			this._booster.p.hidden = boost_back;
			if(boost_straight)
				this._booster.p.asset = "ShipBooster.png";
			else
				this._booster.p.asset = "ShipBoosterOff.png";
		}

		//set plant sprites
		if(this._plants)
		{
			this._plants.p.frame = Q.globals.plantstage
		}
		if(this._cabin)
		{
			this._cabin.p.frame = Math.floor(Math.max(0,(10-Q.globals.food - 1) / 3));
		}
	},

	hit: function(col) {
		if(col.obj)
		{
			if(col.obj.p.damage) //judder on damaging hit
			{
				Q.globals.shiphp -= col.obj.p.damage;

				this.p.angle += (Math.random() - 0.5) * 5;
				this.p.x -= 10;

				if(!this._malfunction)
				{
					if(Q.globals.shiphp < 10)
					{
						this._malfunction = true;
					}
					else if(Q.globals.shiphp < 50)
					{
						this._malfunction = Math.random() < 0.1;
					}
					else
					{
						this._malfunction = Math.random() < 0.01;
					}

					if(this._malfunction)
					{
						Q.audio.play("woop.ogg", {loop:true});
					}
				}
			}
		}
	},

	driver: function(driver) {
		this._driver = driver;
	},

	fix: function() {
		this._malfunction = false;
		Q.audio.stop("woop.ogg");
		Q.globals.fatigue += 5;
	},

	planting: function() {
		Q.globals.fatigue += 5;
		if(Q.globals.plantstage == 0)
		{
			if(Q.globals.seeds > 0)
			{
				Q.globals.seeds--;
				Q.globals.plantstage = 1;
			}
		}
		if(Q.globals.plantstage == 2)
		{
			Q.globals.food += 3;
			Q.globals.plantstage = 0;
		}
	},

	eat: function() {
		if(Q.globals.food > 0)
		{
			Q.globals.food--;
			Q.globals.hunger = 0;
			Q.globals.fatigue = Math.max(0,Q.globals.fatigue-20);
		}
	},

	inserted: function() {

		this._back = this.stage.insert(new Q.Sprite({asset: "ShipBack.png", type: 0, z: -10}), this);
		this._front = this.stage.insert(new Q.Sprite({asset: "ShipOpen.png", type: 0, z: 100}), this);
		this._all = this.stage.insert(new Q.Sprite({asset: "Ship.png", type: 0, z: 100, hidden: true}), this);

		this._boosterup = this.stage.insert(new Q.Sprite({asset: "ShipBoosterUp.png", type: 0, z: 110, hidden: true}), this);
		this._boosterdown = this.stage.insert(new Q.Sprite({asset: "ShipBoosterDown.png", type: 0, z: 110, hidden: true}), this);
		this._booster = this.stage.insert(new Q.Sprite({asset: "ShipBoosterOff.png", type: 0, z: 110}), this);

		this._plants = this.stage.insert(new Q.Sprite({sheet: "plants", type: 0, y: -20, z: -9}), this);
		this._cabin = this.stage.insert(new Q.Sprite({sheet: "cabin", type: 0, x: 20,  y: 20, z: -9}), this);

		for(var i = 0; i < shipPhysics.length; i++)
		{
			var chunk = shipPhysics[i];
			var object = this.stage.insert(new Q.Sprite({points: chunk, type: Q.SPRITE_FRIENDLY, collisionScale: 0, collisionMask: ~Q.SPRITE_FRIENDLY}), this);
			object.add("2d");
			object.on("hit", this, "hit");
		}
	},

});

};
