init_scenes = function(Q) {

var pixelZoom = 2;

//crisper scale
Q.ctx.imageSmoothingEnabled = false;
Q.ctx.mozImageSmoothingEnabled = false;
Q.ctx.webkitImageSmoothingEnabled = false;

// main menu

Q.scene("main", function(stage) {
  
  stage.insert(new Q.UI.Text({x: 512, y: 100, label: "Sarah is a chimp with a spaceship, bravely", color: 'white'}));
  stage.insert(new Q.UI.Text({x: 512, y: 140, label: "going where there are many asteroids.", color: 'white'}));
  stage.insert(new Q.UI.Text({x: 512, y: 280, label: "Use the arrows to move.", color: 'white'}));
  stage.insert(new Q.UI.Text({x: 512, y: 320, label: "Use X to interact, Z or Space to fire (when driving).", color: 'white'}));
  stage.insert(new Q.UI.Text({x: 512, y: 360, label: "As you complete each stage, you will receive a choice of bonuses.", color: 'white'}));
  stage.insert(new Q.UI.Text({x: 512, y: 400, label: "You may choose only one.", color: 'white'}));
  stage.insert(new Q.UI.Text({x: 512, y: 480, label: "Press Space to Begin.", color: 'white'}));

  Q.input.on('fire', stage, function() {
    Q.stageScene("background", 0);
    Q.stageScene("foreground", 2);

    Q.stageScene("game", 1, {sort: true});
    Q.stageScene("hud", 3);
  });

});

//game over

Q.scene("gameover", function(stage) {

  stage.insert(new Q.UI.Text({x: 512, y: 100, label: "Game Over", color: 'white'}));
  
  stage.insert(new Q.UI.Text({x: 512, y: 280, label: "Try not to be discouraged.", color: 'white'}));
  
  stage.insert(new Q.UI.Text({x: 512, y: 360, label: "You made it to level "+Q.globals.level, color: 'white'}));

  stage.insert(new Q.UI.Text({x: 512, y: 480, label: "Press X to Return to the main menu.", color: 'white'}));

  init_globals(Q, true); //wipe save
  globals_save(Q);

  setTimeout( function() {
  Q.input.on('action', stage, function() {
    Q.stageScene("main", 0);
  }); }, 1000 );

});

//ambience

Q.scene("background", function(stage) {
  stage.add("viewport");

  var stars = stage.insert(new Q.Sprite({asset: "back_stars.png", x: 512, y: 288}));

  stage.on("step", function() {
    stage.viewport.scale = Q.stage(1).viewport.scale;

    var ship = Q("Ship", 1).first();
    if(ship)
    {
      stars.p.x = 1024 - ship.p.x * 0.05;
      stars.p.y = 288 - ship.p.y * 0.05;
    }
  });
});

Q.scene("foreground", function(stage) {
  stage.insert(new Q.Sprite({asset: "back_fade.png", x: 512, y: 288}));
});

//game scene

Q.scene("game", function(stage) {

  globals_load(Q);

  var ship = stage.insert(new Q.Ship({x: 200, y:150}));
  var player = stage.insert(new Q.Chimp({x: Q.globals.playerx, y:Q.globals.playery}), ship);

  stage.add("viewport");
  stage.viewport.scale = pixelZoom;
  stage.follow(ship);

  stage.on('step', function(dt) {
    
    var save = Q.globals;

    var x = ship.p.x + 800;
    if(_getShipDistance(x) > 0 &&
        Math.random() < Q.globals.difficulty / 1000)
    {
      stage.insert(new Q.Asteroid({x:x, y:ship.p.y + (Math.random() - 0.5)*800}));
    }

    if(_getShipDistance(ship.p.x) <= 0)
    {
      save.playerx = player.p.x;
      save.playery = player.p.y;
      
      save.difficulty += 10;
      
      save.level++;

      if(Q.globals.plantstage == 1)
        Q.globals.plantstage = 2;

      globals_save(Q);
      ship.p.x = 200;
      ship.p.y = 150;
      Q.stageScene("buffs", 4);
    }

  });

  stage.on('restart', function() {
    Q.stageScene('game',1);
  });
  
  stage.on("destroy",function() {
    player.destroy();
    ship.destroy();
  });

  stage.on('step', function(dt) {
    Q.debug = Q.inputs['debugmode'];
    if(Q.inputs['restart'])
    {
      console.log('restart pressed')
      init_globals(Q, true);
      globals_save(Q);
      stage.trigger('restart');
    }
    if(Q.globals.shiphp <= 0 || Q.globals.chimphp <= 0)
    {
      Q.stageScene("gameover", 0);
      Q.stageScene(null, 1);
      Q.stageScene(null, 2);
      Q.stageScene(null, 3);
      Q.stageScene(null, 4);

      Q.audio.stop("woop.ogg");
    }
  });

});

//buffs choice

Q.scene("buffs", function(stage) {
  
  Q.stage(1).pause();

  stage.insert(new Q.UI.Text({x: 512, y: 200, label: "Choose Your Bonus", color: 'white'}));
  stage.insert(new Q.UI.Text({x: 512, y: 440, label: "(Arrows to move, X to select)", color: 'white'}));

  var container = stage.insert(new Q.UI.Container({x: 512, y: 300, w: 1000, h: 64}));

  var caret = container.insert(new Q.UI.Text({x: -300, y: -40, label: ">", color: 'white'}));

  var texts = [];

  var buffs = Q._shuffle(Q._buffs);

  for(var i = 0; i < 3; i++)
  {
    var buff = buffs[i];
    texts.push(buff);

    container.insert(new Q.UI.Text({
      y: -40 + 40*i,
      label: ""+(i+1)+": "+buff.caption,
      color: 'white'
    }));
  }

  stage._index = 0;

  Q.input.on('up', stage, function() {
    stage._index--;
    if(stage._index < 0)
      stage._index = 2;    
  });

  Q.input.on('down', stage, function() {
    stage._index++;
    if(stage._index > 2)
      stage._index = 0;    
  });

  Q.input.on('action', stage, function() {
    Q.stage(1).unpause();

    if(texts[stage._index])
      texts[stage._index].callback();

    Q.stageScene(null, 4);
  });

  stage.on('step', function(dt) {

    caret.p.y = -40 + 40 * stage._index;

  });
});

//hud

Q.scene("hud", function(stage) {
  var container = stage.insert(new Q.UI.Container({x: 512, y: 530, w: 1000, h: 64}));
  
  var shiphptext = container.insert(new Q.UI.Text({x: -450, prefix: "ship: ", color: 'white'}));
  var ammotext = container.insert(new Q.UI.Text({x: -450, y: 30, prefix: "ammo: ", color: 'white'}));

  var seedtext = container.insert(new Q.UI.Text({x: -250, prefix: "seed: ", color: 'white'}));
  var foodtext = container.insert(new Q.UI.Text({x: -250, y: 30, prefix: "food: ", color: 'white'}));

  var hptext = container.insert(new Q.UI.Text({x: -100, prefix: "hp: ", color: 'white'}));
  var hungertext = container.insert(new Q.UI.Text({x: -100, y:30, prefix: "hun: ", color: 'white'}));
  var sleeptext = container.insert(new Q.UI.Text({x: 50, prefix: "ftg: ", color: 'white'}));
  var disttext = container.insert(new Q.UI.Text({x: 300, prefix: "dist: ", color: 'white'}));

  stage.on('step', function(dt) {
    var save = Q.globals;
    var ship = Q("Ship", 1).first();
    if(save && ship)
    {
      shiphptext.p.label = shiphptext.p.prefix+Math.floor(save.shiphp);
      ammotext.p.label = ammotext.p.prefix+Math.floor(save.ammo);

      seedtext.p.label = seedtext.p.prefix+Math.floor(save.seeds);
      foodtext.p.label = foodtext.p.prefix+Math.floor(save.food);

      hptext.p.label = hptext.p.prefix+Math.floor(save.chimphp);
      hungertext.p.label = hungertext.p.prefix+Math.floor(save.hunger);
      sleeptext.p.label = sleeptext.p.prefix+Math.floor(save.fatigue);
      disttext.p.label = disttext.p.prefix+_getShipDistance(ship.p.x)+"m";
    }
  });
});

_getShipDistance = function(shipx) {
  return Math.floor(Math.max(0,100 - ((shipx-210)/32)));
};

}